@@ -10,11 +10,11 @@ class Sleeper(BaseCommand):
         start_time = time.time()
         target_time = float(target_time)
         
-        print "Sleeping for %s seconds..." % (target_time,)
+        print("Sleeping for {} seconds...".format(target_time))
         time.sleep(target_time)
         
         end_time = time.time()
-        print "Job ran for %f seconds" % (end_time-start_time)
+        print("Job ran for {} seconds".format(end_time-start_time))
 
 class InfiniteWaiter(BaseCommand):
     args = ''
@@ -23,5 +23,5 @@ class InfiniteWaiter(BaseCommand):
     def handle(self, *args, **options):
         while 1:
             time.sleep(1)
-            print 'Waiting...'
-            
\ No newline at end of file
+            print('Waiting...')
+            
